# Overview

This demo presents a remote management of a device. It mounts a HTTP Web server on the board to manage a thermostat (current and target temperature). 

This demo can also be linked to a cloud to control the thermostat and receive data from it.

![generalInteraction](screenshots/generalInteraction.PNG)

The user uses the web page to modify the desired temperature. This web page is hosted by the device.

![webView](screenshots/webPage.PNG)


# Usage

## Run the demo

To run the demo on any compatible board (see requirements section).

### Run on MicroEJ Simulator
1. Right Click on [com.microej.demo.thermorest.Main](com.microej.demo.thermorest/src/main/java/com/microej/demo/thermorest/Main.java)
2. Select **Run as -> MicroEJ Application**


* The demo will be running on the PC localhost
* The demo will publish to MQTT broker at `tcp://iot.eclipse.org:1883`
    * Topic `MicroEJ/thermostat/update/target` receive target values.
    * Topic `MicroEJ/thermostat/update/temperature` receive temperatures values.
    * Topic `MicroEJ/thermostat/ip` receive target values.
    * Topic `MicroEJ/thermostat/set/target` can be used to update the value.
* A web page is mounted at [Board IP]:[PORT]/aws.html to configure the AWS credentials at run time, please see **Use AWS cloud connector** section.

### Run on device

#### Build

1. Right Click on [com.microej.demo.thermorest.Main](com.microej.demo.thermorest/src/main/java/com/microej/demo/thermorest/Main.java)
2. Select **Run as -> Run Configuration**
3. Select **MicroEJ Application** configuration kind
4. Click on **New launch configuration** icon
5. In **Execution** tab
   1. In **Target** frame, in **Platform** field, select a relevant platform (but not a virtual device)
   2. In **Execution** frame
      1. Select **Execute on Device**
      2. In **Settings** field, select **Build & Deploy**
6. Press **Apply**
7. Press **Run**
8. Copy the generated `.out` file path shown by the console

#### Flash

1. Use the appropriate flashing tool.


## Execution flow

1. Run the demo (see above).
2. Once the server is started a trace will be printed like `Server started please browse to http://[Board IP]:[SERVER PORT]`.
3. Open a web browser on a device (PC, smartphone...) on the same network as the board.
4. Browse to **http://[Board IP]:[SERVER PORT]**.
5. Change the temperature using the web browser UI.

# Extend the demo

This demo can be modified to be extended:
* HeadlessThermostat can be observed to be notified when a cloudConnector is added or deleted.
* ThermostatModel can be registered as listener to be notified on temperature and target changes.
* HeadlessThermostat loads its model from the serviceLoader, modify the properties.list to change it.
  * MicroEJ provides an example of implementation, AutomaticThermostatModel modifying the temperature to reach the target over time.
  * A new implementation can be done (for instance using a SNI functions to get the temperature).

## Use AWS cloud connector

This demo is pre-configured to use AWS cloud connectivity; it still requires to be setup with your AWS credentials and configuration.

### Getting ready with AWS IoT

* Create AWS account through [AWS console](https://aws.amazon.com/console/).
* Go to `AWS IoT`.
* Go to `Secure` > `Policies`.
* Create a policy (it describes what your device will be able to do like subscribing and publishing).
* Name it and configure it like this (copy/paste is available by clicking on `Advanced mode` of the `Add statements` section) :
   ```
   {
     "Version": "2012-10-17",
     "Statement": [
       {
         "Action": [
           "iot:Publish",
           "iot:Subscribe",
           "iot:Connect",
           "iot:Receive"
         ],
         "Effect": "Allow",
         "Resource": [
           "*"
         ]
       }
     ]
   }
   ```
* Click on create.
* Go to `Manage`.
* Click on `Create`.
* Click on `Create a single thing`.
* Name your thing and click on `Next`.
* Choose the `One-click certificate creation (recommended)` option by clicking on `Create certificate`.
* On the `Certificate created` page, download every certificates and keys.
* Click on the `Activate` button to enable the certificate authentication of your thing.
* Click on `Attach a policy`.
* Select the previously created policy.

The AWS IoT full documentation can be found [here](https://docs.aws.amazon.com/iot/latest/developerguide/iot-console-signin.html)

### Getting ready with the certificates

* Transform the private key like this using [OpenSSL](https://www.openssl.org/source/):
	`openssl.exe pkcs8 -inform PEM -in myprivate.pem.key -topk8 -outform DER -out myprivate.der -v1 PBE-SHA1-3DES -passout pass:awsdemo`

There are two ways to provide this elements to the demo, to embed them into the demo's binary or to provide them at run time:

#### To embed them into into the demo's binary

* Add your private key and certificate in the folder
[aws.certificates.device/](src\main\resources\aws\certificates\device).
* Add the paths to your private key and certificate in [aws.certificates.resources.list](src\main\resources\aws\certificates\aws.certificates.resources.list)
   ```
   /aws/certificates/device/mycertificate.pem.crt
   /aws/certificates/device/myprivate.der
   ```
* Modify the properties file that will be used to initialize the SSL context, located at [aws.properties.list](src\main\resources\aws\certificates\aws.properties.list)
   ```
   # Path to the device certificate.
   aws.device.certificate.path=/aws/certificates/device/mycertificate.pem.crt
   # Path to the device private key.
   aws.device.private.key.path=/aws/certificates/device/myprivate.der
   # Password used for the device private key.
   aws.device.private.key.password=awsdemo
   ```
   
#### To provide them at runtime

Go to [Board IP]/aws.html and provide the two files plus the properties below
   
### Getting ready with the application configuration

* In order to find your broker host, go to your AWS IoT Console, click on `Manage` > `Things` and select your Thing previously created. Then click on `Interact` and the broker host is shown under the HTTPS section and should look like this : `[myowndomainid].amazonaws.com`
* Your host `[myowndomainid].amazonaws.com` may have `-ats` in its path, if so, remove it. `xxxxxxxxxx-ats.iot.yyyyyyyyy.amazonaws.com` => `xxxxxxxxxx.iot.yyyyyyyyy.amazonaws.com`.

#### To embed them into into the demo's binary

* Modify the properties file that will be used to initialize the SSL context, located at [aws.properties.list](src\main\resources\aws\certificates\aws.properties.list)
	```
	# the path of the device certificate
	certificate.file.name=/certificates/device/mycertificate.pem.crt
	# the path of the device private key (encoded with the previous openssl command)
	private.key.file.name=/certificates/device/myprivate.der
	# the password used in the previous openssl command (the part afer pass:) -passout pass:awsdemo
	keystore.password=awsdemo
	```
	
#### To provide them at runtime

Go to [Board IP]/aws.html and provide the two files plus the properties below
	
## AWS IoT dashboard

The AWS IoT console provides some tools to monitor the activity on the broker. 
* Go in the `Monitor` section of the console to see graphs of successful connections to the broker and statistics on the messaging.
You can also subscribe on a topic through the console in order to see arriving messages from your device: 
* Go to `Test`
* In the `Subscription topic` section, indicate the topic to subscribe to:
    * Topic `MicroEJ/thermostat/update/target` receive target values.
    * Topic `MicroEJ/thermostat/update/temperature` receive target values.
    * Topic `MicroEJ/thermostat/ip` receive target values.
* Click on `Subscribe to topic`
* When the application is running, you should see messages displayed in the AWS IoT console


# Requirements

This demo requires a MicroEJ platform that supports:
  - EDC-1.2 or higher
  - BON-1.2 or higher
  - NET-1.1 or higher
  - SSL-2.1 or higher

# Dependencies

_All dependencies are retrieved transitively by Ivy resolver_.

# Source

N/A

# Restrictions

None.

---
_Copyright 2019 MicroEJ Corp. All rights reserved._  
_For demonstration purpose only. _  
_MicroEJ Corp. PROPRIETARY. Use is subject to license terms._  