/*
 * Java
 *
 * Copyright 2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.authz;

import ej.authz.acl.AccessControlList;

/**
 * Interface for access control.
 * <p>
 * {@link #isAuthorized(Object, Object, Object)} computes whether or not the <b>user</b> can, in the <b>environment</b>,
 * access the <b>resource</b> to enforce a security policy.
 *
 * @param <U>
 *            the type used to represent the user.
 * @param <E>
 *            the type used to represent the environment, can also contain information on the action requested (read,
 *            write, ...).
 * @param <R>
 *            the type used to represent the resource.
 * @see AccessControlList
 */
public interface AccessControlEngine<U, E, R> {

	/**
	 * Computes whether or not the {@code user} can, in the {@code environment}, access the {@code resource}.
	 *
	 * @param user
	 *            the initiator of the request.
	 * @param environment
	 *            the context of the request.
	 * @param resource
	 *            the target of the request.
	 * @return {@code true} if the request is authorized by the policy, {@code false} otherwise.
	 */
	boolean isAuthorized(U user, E environment, R resource);

}
