/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.impl;

import java.util.ArrayList;
import java.util.List;

import ej.basedriver.Controller;
import ej.basedriver.Node;
import ej.ecom.Device;


/**
 * This abstract class gives a structure and mechanisms for developers who wish to create a {@link Node} for a protocol.
 * 
 * @param <ConcreteController>
 *            the type of the controller which manage this node.
 * 
 * 
 */
public abstract class AbstractNode<ConcreteController extends Controller> implements Node {

	/**
	 * List of child.
	 */
	protected final List<Device> children = new ArrayList<>();

	/**
	 * The node's controller.
	 */
	protected final ConcreteController controller;

	/**
	 * Create a new node. A node is associated to a controller. This controller is its parent
	 * 
	 * @param controller
	 *            the associated controller
	 */
	public AbstractNode(ConcreteController controller) {
		this.controller = controller;
	}

	/**
	 * Add a profile as a child of this node. All profiles registered with this method can be retrieved with {@link #getChildren()}.
	 * 
	 * @param child
	 *            a new child for this node
	 */
	public void addChild(Device child) {
		children.add(child);
	}

	@Override
	public Device[] getChildren() {
		return children.toArray(new Device[children.size()]);
	}

	@Override
	public Device getParent() {
		return controller;
	}

	/**
	 * Get the controller to which this device is connected.
	 * 
	 * @return the associated controller
	 */
	public ConcreteController getController() {
		return controller;
	}
}
