/*
 * Java
 *
 * Copyright 2016-2017 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.data.channel;

import java.io.IOException;

import ej.data.DataWriter;

/**
 * A channel of data. The implementor ensures data is published in sequences. At most one data is published at a time on a channel.
 */
public interface DataChannel {

	/**
	 * Requests a new publication to this channel and returns its associated data writer.
	 * The data will be automatically published once the caller has fully written a value in the data writer.
	 * @return the dedicated {@link DataWriter}.
	 * @throws IOException if nothing can be published on the channel.
	 */
	public DataWriter newPublication() throws IOException;

	/**
	 * Returns the name of the channel.
	 * @return the name of the channel.
	 */
	public String getName();

}
