/*
 * Java
 *
 * Copyright 2019 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.gnss;

import java.io.IOException;

/**
 * Implementation of the GnssManager function that calls the native function interface
 */
public class GnssManager {

	/**
	 * Enum state machine for GnssManager
	 */
	public enum GnssManagerState {
		/**
		 * idle state
		 */
		IDLE,
		/**
		 * initialized state
		 */
		INITIALIZED,
		/**
		 * Positioning polling started
		 */
		STARTED,
		/**
		 * Positioning polling stopped
		 */
		STOPPED,
		/**
		 * Close the GnssManager. Necessary if some closure needs to be done in C-side of if you want to stop the
		 * GnssManager and not the application
		 */
		CLOSED;
	}

	/**
	 * Private constructor to forbid the creation of a GnssManager object.
	 *
	 */
	private GnssManager() {
		throw new RuntimeException();
	}

	/**
	 * Read the position. If no data can be read throw a native exception Set the data to invalid if no signal is found
	 * This functions is blocking until new data has arrived from the low level implementation.
	 *
	 * @throws IOException
	 *             if no signal was found or if low level function reading the GNSS information failed
	 *
	 */
	public void readPosition() throws IOException {
		throw new RuntimeException();
	}

	/**
	 * SwitchOn Positioning polling on the system.
	 *
	 * * @throws IOException if turning the polling ON failed.
	 */
	public void switchOn() throws IOException {
		throw new RuntimeException();
	}

	/**
	 * SwitchOff Positioning polling on the system.
	 *
	 * @throws IOException
	 *             if turning the polling OFF failed
	 */
	public void switchOff() throws IOException {
		throw new RuntimeException();
	}

	/**
	 * Close the manager instance. After this method is called no GnssManager functionality will be available until you
	 * restart the VM.
	 *
	 * @throws IOException
	 *             if closing the GnssManager and its low level component on board failed
	 */
	public void closeManager() throws IOException {
		throw new RuntimeException();
	}

	/**
	 * Get the latest latitude data in degree.
	 *
	 * @return latitude positioning data.
	 */
	public float getLatitude() {
		throw new RuntimeException();
	}

	/**
	 * Return the latest obtained altitude in meters data.
	 *
	 * @return longitude positioning data.
	 */
	public float getAltitude() {
		throw new RuntimeException();
	}

	/**
	 * Return the latest obtained longitude data in degree.
	 *
	 * @return longitude positioning data.
	 */
	public float getLongitude() {
		throw new RuntimeException();
	}

	/**
	 * Return the latest obtained velocity in m/s data.
	 *
	 * @return velocity positioning data.
	 */
	public float getVelocity() {
		throw new RuntimeException();
	}

	/**
	 * Get the epoch time UTC.
	 *
	 * @return Calendar DateTime.
	 */
	public long getTime() {
		throw new RuntimeException();
	}

	/**
	 * Return the singleton instance of GnssManager.
	 *
	 * @return singleton instance of GnssManager.
	 */
	public static GnssManager getInstance() {
		throw new RuntimeException();
	}
}
