/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.container;

/**
 * Represents a rectangle.
 */
public class Rectangle {

	private int x;
	private int y;
	private int width;
	private int height;

	/**
	 * Creates an empty rectangle (all its bounds are 0).
	 */
	public Rectangle() {
		this.x = 0;
		this.y = 0;
		this.width = 0;
		this.height = 0;
	}

	/**
	 * Creates a rectangle specifying its bounds.
	 *
	 * @param x
	 *            the x to set.
	 * @param y
	 *            the y to set.
	 * @param width
	 *            the width to set.
	 * @param height
	 *            the height to set.
	 *
	 */
	public Rectangle(int x, int y, int width, int height) {
		this.x = x;
		this.y = y;
		this.width = width;
		this.height = height;
	}

	/**
	 * Creates a rectangle from the bounds of another rectangle.
	 *
	 * @param rectangle
	 *            the other rectangle.
	 */
	public Rectangle(Rectangle rectangle) {
		this.x = rectangle.x;
		this.y = rectangle.y;
		this.width = rectangle.width;
		this.height = rectangle.height;
	}

	/**
	 * Gets the x coordinate.
	 *
	 * @return the x.
	 */
	public int getX() {
		return this.x;
	}

	/**
	 * Sets the x coordinate.
	 *
	 * @param x
	 *            the x to set.
	 */
	public void setX(int x) {
		this.x = x;
	}

	/**
	 * Gets the y coordinate.
	 *
	 * @return the y.
	 */
	public int getY() {
		return this.y;
	}

	/**
	 * Sets the y coordinate.
	 *
	 * @param y
	 *            the y to set.
	 */
	public void setY(int y) {
		this.y = y;
	}

	/**
	 * Gets the width.
	 *
	 * @return the width.
	 */
	public int getWidth() {
		return this.width;
	}

	/**
	 * Sets the width.
	 *
	 * @param width
	 *            the width to set.
	 */
	public void setWidth(int width) {
		this.width = width;
	}

	/**
	 * Gets the height.
	 *
	 * @return the height.
	 */
	public int getHeight() {
		return this.height;
	}

	/**
	 * Sets the height.
	 *
	 * @param height
	 *            the height to set.
	 */
	public void setHeight(int height) {
		this.height = height;
	}

	/**
	 * Sets the location of the rectangle.
	 *
	 * @param x
	 *            the x to set.
	 * @param y
	 *            the y to set.
	 */
	public void setLocation(int x, int y) {
		this.x = x;
		this.y = y;
	}

	/**
	 * Sets the size of the rectangle.
	 *
	 * @param width
	 *            the width to set.
	 * @param height
	 *            the height to set.
	 */
	public void setSize(int width, int height) {
		this.width = width;
		this.height = height;
	}

	/**
	 * Sets the bounds of the rectangle.
	 *
	 * @param x
	 *            the x to set.
	 * @param y
	 *            the y to set.
	 * @param width
	 *            the width to set.
	 * @param height
	 *            the height to set.
	 */
	public void setBounds(int x, int y, int width, int height) {
		this.x = x;
		this.y = y;
		this.width = width;
		this.height = height;
	}

	/**
	 * Shifts the location of the rectangle.
	 *
	 * @param xShift
	 *            the x shift.
	 * @param yShift
	 *            the y shift.
	 */
	public void move(int xShift, int yShift) {
		this.x += xShift;
		this.y += yShift;
	}

	/**
	 * Increments the size of the rectangle.
	 *
	 * @param widthIncrement
	 *            the width to add.
	 * @param heightIncrement
	 *            the height to add.
	 */
	public void incrementSize(int widthIncrement, int heightIncrement) {
		this.width = Math.max(0, this.width + widthIncrement);
		this.height = Math.max(0, this.height + heightIncrement);
	}

	/**
	 * Decrements the size of the rectangle.
	 *
	 * @param widthDecrement
	 *            the width to remove.
	 * @param heightDecrement
	 *            the height to remove.
	 */
	public void decrementSize(int widthDecrement, int heightDecrement) {
		incrementSize(-widthDecrement, -heightDecrement);
	}

	/**
	 * Updates the rectangle bounds.
	 *
	 * @param xShift
	 *            the x shift.
	 * @param yShift
	 *            the y shift.
	 * @param widthIncrement
	 *            the width to add.
	 * @param heightIncrement
	 *            the height to add.
	 */
	public void update(int xShift, int yShift, int widthIncrement, int heightIncrement) {
		move(xShift, yShift);
		incrementSize(widthIncrement, heightIncrement);
	}

}
