/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.dimension;

import ej.annotation.Nullable;
import ej.mwt.MWT;
import ej.style.container.Rectangle;

/**
 * Dimension with fixed width and/or height.
 */
public class FixedDimension implements Dimension {

	private int width;
	private int height;

	/**
	 * Creates a fixed dimension without constraint.
	 */
	public FixedDimension() {
		this.width = MWT.NONE;
		this.height = MWT.NONE;
	}

	/**
	 * Creates a fixed dimension with constraints.
	 *
	 * @param width
	 *            the width to set.
	 * @param height
	 *            the height to set.
	 */
	public FixedDimension(int width, int height) {
		this.width = width;
		this.height = height;
	}

	/**
	 * Sets the width.
	 *
	 * @param width
	 *            the width to set.
	 */
	public void setWidth(int width) {
		this.width = width;
	}

	/**
	 * Sets the height.
	 *
	 * @param height
	 *            the height to set.
	 */
	public void setHeight(int height) {
		this.height = height;
	}

	/**
	 * Sets the width and height.
	 *
	 * @param width
	 *            the width to set.
	 * @param height
	 *            the height to set.
	 */
	public void setSize(int width, int height) {
		this.width = width;
		this.height = height;
	}

	@Override
	public void apply(Rectangle contentBounds, Rectangle sizeHint) {
		if (this.width != MWT.NONE) {
			contentBounds.setWidth(this.width);
		} else {
			contentBounds.setWidth(sizeHint.getWidth());
		}
		if (this.height != MWT.NONE) {
			contentBounds.setHeight(this.height);
		} else {
			contentBounds.setHeight(sizeHint.getHeight());
		}
	}

	@Override
	public boolean equals(@Nullable Object obj) {
		if (obj instanceof FixedDimension) {
			FixedDimension dimension = (FixedDimension) obj;
			return this.width == dimension.width && this.height == dimension.height;
		}
		return false;
	}

	@Override
	public int hashCode() {
		// Since the fields are not final, they can't be used to compute a constant hashcode.
		return 0;
	}

}
