package ej.style.selector.combinator;

import ej.style.Element;
import ej.style.Selector;

/**
 * An 'or' combinator selects the elements selected by at least one of its inner selectors.
 */
public class OrCombinator extends Combinator {

	/**
	 * Creates an 'or' combinator.
	 *
	 * @param selector1
	 *            the first child.
	 * @param selector2
	 *            the second child.
	 */
	public OrCombinator(Selector selector1, Selector selector2) {
		super(selector1, selector2);
	}

	/**
	 * Creates an 'or' combinator.
	 *
	 * @param selectors
	 *            the list of selectors.
	 * @throws IllegalArgumentException
	 *             if there is less than two selectors.
	 */
	public OrCombinator(Selector... selectors) {
		super(selectors);
	}

	@Override
	public boolean fit(Element element) {
		for (Selector selector : this.selectors) {
			if (selector.fit(element)) {
				return true;
			}
		}
		return false;
	}

}
