/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.widget.basic.image;

import ej.microui.display.GraphicsContext;
import ej.microui.display.Image;
import ej.style.Style;
import ej.style.container.Rectangle;
import ej.style.util.StyleHelper;
import ej.widget.basic.Box;

/**
 * A toggle using some images to render.
 */
public abstract class ImageToggle extends Box {

	@Override
	public void renderContent(GraphicsContext g, Style style, Rectangle bounds) {
		int width = bounds.getWidth();
		int height = bounds.getHeight();

		int foregroundColor = style.getForegroundColor();
		g.setColor(foregroundColor);
		g.setFont(StyleHelper.getFont(style));

		if (isChecked()) {
			g.drawImage(getCheckedImage(), width >> 1, height >> 1, GraphicsContext.HCENTER | GraphicsContext.VCENTER);
		} else {
			g.drawImage(getUncheckedImage(), width >> 1, height >> 1,
					GraphicsContext.HCENTER | GraphicsContext.VCENTER);
		}
	}

	@Override
	public Rectangle validateContent(Style style, Rectangle bounds) {
		Image checkedImage = getCheckedImage();
		Image uncheckedImage = getUncheckedImage();
		int width = Math.max(checkedImage.getWidth(), uncheckedImage.getWidth());
		int height = Math.max(checkedImage.getHeight(), uncheckedImage.getHeight());
		return new Rectangle(0, 0, width, height);
	}

	private Image getCheckedImage() {
		Image image = StyleHelper.getImage(getCheckedImagePath());
		if (image == null) {
			throw new NullPointerException();
		}
		return image;
	}

	private Image getUncheckedImage() {
		Image image = StyleHelper.getImage(getUncheckedImagePath());
		if (image == null) {
			throw new NullPointerException();
		}
		return image;
	}

	/**
	 * Gets the path of the image corresponding to the checked state of the toggle.
	 *
	 * @return the path of the image corresponding to the checked state of the toggle.
	 */
	protected abstract String getCheckedImagePath();

	/**
	 * Gets the path of the image corresponding to the unchecked state of the toggle.
	 *
	 * @return the path of the image corresponding to the unchecked state of the toggle.
	 */
	protected abstract String getUncheckedImagePath();

}
