/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.widget.basic.picto;

import ej.microui.display.Font;
import ej.microui.display.GraphicsContext;
import ej.style.Style;
import ej.style.container.Rectangle;
import ej.style.util.StyleHelper;
import ej.widget.basic.Box;

/**
 * A toggle using some pictos to render.
 */
public abstract class PictoToggle extends Box {

	@Override
	public void renderContent(GraphicsContext g, Style style, Rectangle bounds) {
		char picto = isChecked() ? getCheckedPicto() : getUncheckedPicto();
		g.setFont(StyleHelper.getFont(style));
		g.setColor(style.getForegroundColor());
		g.drawChar(picto, bounds.getWidth() >> 1, bounds.getHeight() >> 1,
				GraphicsContext.HCENTER | GraphicsContext.VCENTER);
	}

	@Override
	public Rectangle validateContent(Style style, Rectangle bounds) {
		Font font = StyleHelper.getFont(style);
		char picto = isChecked() ? getCheckedPicto() : getUncheckedPicto();
		return new Rectangle(0, 0, font.charWidth(picto), font.getHeight());
	}

	/**
	 * Gets the picto corresponding to the checked state of the toggle.
	 *
	 * @return the picto corresponding to the checked state of the toggle.
	 */
	protected abstract char getCheckedPicto();

	/**
	 * Gets the picto corresponding to the unchecked state of the toggle.
	 *
	 * @return the picto corresponding to the unchecked state of the toggle.
	 */
	protected abstract char getUncheckedPicto();

}
