/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.widget.composed;

import ej.annotation.Nullable;
import ej.giml.annotation.Element;
import ej.giml.annotation.ElementChild;
import ej.giml.annotation.ElementConstructor;
import ej.giml.annotation.ElementRequiredAttribute;
import ej.mwt.Widget;
import ej.style.image.ImageLoader;
import ej.style.util.StyleHelper;
import ej.widget.basic.Image;

/**
 * A facility to use a button that displays an image.
 * <p>
 * It is simply a button composite that contains an image widget.
 *
 * @see Image
 * @deprecated see {@link ej.widget.basic.ButtonImage}
 */
@Deprecated
@Element(friendlyName = "Button Image")
public class ButtonImage extends ButtonWrapper {

	private final Image image;

	/**
	 * Creates a button without image.
	 */
	public ButtonImage() {
		this((ej.microui.display.Image) null);
	}

	/**
	 * Creates a button with the path to the image to display.
	 * <p>
	 * The image loader service is used to load the image from the given path.
	 *
	 * @param source
	 *            the path to the source to display.
	 * @throws NullPointerException
	 *             if the given source is <code>null</code>.
	 * @see ImageLoader#getImage(String)
	 */
	@ElementConstructor
	public ButtonImage(@ElementRequiredAttribute String source) {
		this(StyleHelper.getImage(source));
	}

	/**
	 * Creates a button with the given image to display.
	 *
	 * @param source
	 *            the image to display.
	 */
	public ButtonImage(@Nullable ej.microui.display.Image source) {
		this.image = new Image(source);
		super.setWidget(this.image);
	}

	@Override
	@ElementChild(prefix = "setWidget", disabled = true)
	public void setWidget(Widget widget) {
		throw new IllegalArgumentException();
	}

	/**
	 * Gets the image contained in the button.
	 *
	 * @return the image contained in the button.
	 */
	public Image getImage() {
		return this.image;
	}

	/**
	 * Sets the source image to display for this button.
	 *
	 * @param source
	 *            the path to new image to display.
	 * @throws NullPointerException
	 *             if the given image is <code>null</code>.
	 * @see Image#setSource(String)
	 */
	public void setSource(String source) {
		this.image.setSource(source);
	}

	/**
	 * Sets the source image to display for this button.
	 *
	 * @param source
	 *            the image to display.
	 * @throws NullPointerException
	 *             if the given image is <code>null</code>.
	 * @see Image#setSource(ej.microui.display.Image)
	 */
	public void setSource(ej.microui.display.Image source) {
		this.image.setSource(source);
	}

	/**
	 * Gets the image displayed by this button.
	 * <p>
	 * The image is hold by the inner image widget.
	 *
	 * @return the image.
	 * @see Image#getSource()
	 */
	@Nullable
	public ej.microui.display.Image getSource() {
		return this.image.getSource();
	}

}
