/*******************************************************************************
 * Copyright 2015-2019 MicroEJ Corp. This file has been modified by MicroEJ Corp.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * and Eclipse Distribution License v1.0 which accompany this distribution.
 *
 * The Eclipse Public License is available at
 *    http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 *   http://www.eclipse.org/org/documents/edl-v10.php.
 */


package org.eclipse.paho.client.mqttv3.logging;

import ej.util.message.Level;
import ej.util.message.basic.BasicMessageBuilder;

public class MicroEJInternalLoggerFactory implements InternalLoggerFactory, Logger {

	@Override
	public Logger getLogger(String messageCatalogName, String loggerID, String overrideloggerClassName) {
		return this;
	}

	@Override
	public String getLoggingProperty(String name) {
		return null;
	}

	private java.util.logging.Logger	julLogger			= null;
	private String						resourceName		= null;

	private java.util.logging.Logger getLogger () {
		if (julLogger == null) {
			julLogger = java.util.logging.Logger.getLogger("MQTT");
		}

		return julLogger;
	}


	@Override
	public void setResourceName(String logContext) {
		this.resourceName = logContext;
	}

	@Override
	public boolean isLoggable(int level) {
		return getLogger().isLoggable(mapJULLevel(level));
	}

	@Override
	public void severe(String sourceClass, String sourceMethod, int errorCode) {
		log(SEVERE, sourceClass, sourceMethod, errorCode, null, null);
	}

	@Override
	public void severe(String sourceClass, String sourceMethod, int errorCode, Object[] inserts) {
		log(SEVERE, sourceClass, sourceMethod, errorCode, inserts, null);
	}

	@Override
	public void severe(String sourceClass, String sourceMethod, int errorCode, Object[] inserts, Throwable thrown) {
		log(SEVERE, sourceClass, sourceMethod, errorCode, inserts, thrown);
	}

	@Override
	public void warning(String sourceClass, String sourceMethod, int errorCode) {
		log(WARNING, sourceClass, sourceMethod, errorCode, null, null);
	}

	@Override
	public void warning(String sourceClass, String sourceMethod, int errorCode, Object[] inserts) {
		log(WARNING, sourceClass, sourceMethod, errorCode, inserts, null);
	}

	@Override
	public void warning(String sourceClass, String sourceMethod, int errorCode, Object[] inserts, Throwable thrown) {
		log(WARNING, sourceClass, sourceMethod, errorCode, inserts, thrown);
	}

	@Override
	public void info(String sourceClass, String sourceMethod, int errorCode) {
		log(INFO, sourceClass, sourceMethod, errorCode, null, null);
	}

	@Override
	public void info(String sourceClass, String sourceMethod, int errorCode, Object[] inserts) {
		log(INFO, sourceClass, sourceMethod, errorCode, inserts, null);
	}

	@Override
	public void info(String sourceClass, String sourceMethod, int errorCode, Object[] inserts, Throwable thrown) {
		log(INFO, sourceClass, sourceMethod, errorCode, inserts, thrown);
	}

	@Override
	public void config(String sourceClass, String sourceMethod, int errorCode) {
		log(CONFIG, sourceClass, sourceMethod, errorCode, null, null);
	}

	@Override
	public void config(String sourceClass, String sourceMethod, int errorCode, Object[] inserts) {
		log(CONFIG, sourceClass, sourceMethod, errorCode, inserts, null);
	}

	@Override
	public void config(String sourceClass, String sourceMethod, int errorCode, Object[] inserts, Throwable thrown) {
		log(CONFIG, sourceClass, sourceMethod, errorCode, inserts, thrown);
	}

	@Override
	public void log(int level, String sourceClass, String sourceMethod, int errorCode, Object[] inserts,
			Throwable thrown) {
		java.util.logging.Level julLevel = mapJULLevel(level);
		char l = mapMessageLevel(level);
		if (getLogger().isLoggable(julLevel)) {
			log0(julLevel, l, sourceClass, sourceMethod, errorCode, inserts, thrown);
		}
	}

	@Override
	public void fine(String sourceClass, String sourceMethod, int errorCode) {
		trace(FINE, sourceClass, sourceMethod, errorCode, null, null);
	}

	@Override
	public void fine(String sourceClass, String sourceMethod, int errorCode, Object[] inserts) {
		trace(FINE, sourceClass, sourceMethod, errorCode, inserts, null);
	}

	@Override
	public void fine(String sourceClass, String sourceMethod, int errorCode, Object[] inserts, Throwable ex) {
		trace(FINE, sourceClass, sourceMethod, errorCode, inserts, ex);
	}

	@Override
	public void finer(String sourceClass, String sourceMethod, int errorCode) {
		trace(FINER, sourceClass, sourceMethod, errorCode, null, null);
	}

	@Override
	public void finer(String sourceClass, String sourceMethod, int errorCode, Object[] inserts) {
		trace(FINER, sourceClass, sourceMethod, errorCode, inserts, null);
	}

	@Override
	public void finer(String sourceClass, String sourceMethod, int errorCode, Object[] inserts, Throwable ex) {
		trace(FINER, sourceClass, sourceMethod, errorCode, inserts, ex);
	}

	@Override
	public void finest(String sourceClass, String sourceMethod, int errorCode) {
		trace(FINEST, sourceClass, sourceMethod, errorCode, null, null);
	}

	@Override
	public void finest(String sourceClass, String sourceMethod, int errorCode, Object[] inserts) {
		trace(FINEST, sourceClass, sourceMethod, errorCode, inserts, null);
	}

	@Override
	public void finest(String sourceClass, String sourceMethod, int errorCode, Object[] inserts, Throwable ex) {
		trace(FINEST, sourceClass, sourceMethod, errorCode, inserts, ex);
	}


	@Override
	public void trace(int level, String sourceClass, String sourceMethod, int errorCode, Object[] inserts,
			Throwable ex) {
		java.util.logging.Level julLevel = mapJULLevel(level);
		char l = mapMessageLevel(level);
		boolean isJULLoggable = getLogger().isLoggable(julLevel);
		if (isJULLoggable) {
			log0(julLevel, l, sourceClass, sourceMethod, errorCode, inserts, ex);
		}
	}

	private void log0(java.util.logging.Level julLevel, char messageLevel, String sourceClass, String sourceMethod,
			int errorCode,
			Object[] inserts, Throwable thrown) {
		BasicMessageBuilder messageBuilder = new BasicMessageBuilder();
		String msg;
		if (inserts == null) {
			msg = messageBuilder.buildMessage(messageLevel, this.getLogger().getName(), errorCode);
		} else {
			msg = messageBuilder.buildMessage(messageLevel, this.getLogger().getName(), errorCode, inserts);
		}
		if (thrown != null) {
			getLogger().log(julLevel, msg, thrown);
		} else {
			getLogger().log(julLevel, msg);
		}
	}

	/**
	 * @param level
	 * @return
	 */
	private char mapMessageLevel(int level) {
		switch (level) {
		case SEVERE:
			return Level.SEVERE;
		case WARNING:
			return Level.WARNING;
		case INFO:
			return Level.INFO;
		case CONFIG:
			return Level.CONFIG;
		case FINE:
			return Level.FINE;
		case FINER:
			return Level.FINER;
		case FINEST:
			return Level.FINEST;
		default:
			return Level.INFO;
		}
	}

	private java.util.logging.Level mapJULLevel(int level) {
		java.util.logging.Level julLevel = null;

		switch (level) {
		case SEVERE:
			julLevel = java.util.logging.Level.SEVERE;
			break;
		case WARNING:
			julLevel = java.util.logging.Level.WARNING;
			break;
		case INFO:
			julLevel = java.util.logging.Level.INFO;
			break;
		case CONFIG:
			julLevel = java.util.logging.Level.CONFIG;
			break;
		case FINE:
			julLevel = java.util.logging.Level.FINE;
			break;
		case FINER:
			julLevel = java.util.logging.Level.FINER;
			break;
		case FINEST:
			julLevel = java.util.logging.Level.FINEST;
			break;

		default:
		}

		return julLevel;
	}

	@Override
	public void dumpTrace() {
	}
}
